-- Create schema
CREATE SCHEMA BROKERS DEFAULT CHARACTER SET utf8 ;

-- Create users for our demo
-- 
-- Ideally, % should be a defined address. Will struggle later.
--
CREATE USER 'demo1'@'%' IDENTIFIED BY 'password';
CREATE USER 'demo2'@'%' IDENTIFIED BY 'password';
CREATE USER 'demo3'@'%' IDENTIFIED BY 'password';
CREATE USER 'demo4'@'%' IDENTIFIED BY 'password';
-- Grant privileges
GRANT ALL PRIVILEGES ON BROKERS.* TO 'demo1'@'%' WITH GRANT OPTION;
GRANT ALL PRIVILEGES ON BROKERS.* TO 'demo2'@'%' WITH GRANT OPTION;
GRANT ALL PRIVILEGES ON BROKERS.* TO 'demo3'@'%' WITH GRANT OPTION;
GRANT ALL PRIVILEGES ON BROKERS.* TO 'demo4'@'%' WITH GRANT OPTION;
FLUSH PRIVILEGES;
-- Alter user to use MySQL Native password
-- https://github.com/mysqljs/mysql/issues/2248
ALTER USER 'demo1'@'%' IDENTIFIED WITH mysql_native_password BY 'password';
ALTER USER 'demo2'@'%' IDENTIFIED WITH mysql_native_password BY 'password';
ALTER USER 'demo3'@'%' IDENTIFIED WITH mysql_native_password BY 'password';
ALTER USER 'demo4'@'%' IDENTIFIED WITH mysql_native_password BY 'password';
FLUSH PRIVILEGES;
-- Monitor user
CREATE USER 'monitor'@'%' IDENTIFIED BY 'password';
GRANT ALL PRIVILEGES ON *.* TO 'monitor'@'%';
FLUSH PRIVILEGES;
-- Create tables
CREATE TABLE BROKERS.BROKER_DETAILS (
  BROKER_ADDRESS VARCHAR(256) NULL,
  DATA_CHECKSUM VARCHAR(64) NULL,
  DELETE_FL VARCHAR(32) NULL,
  DISABLE_FL VARCHAR(32) NULL,
  EMAIL_ADDRESS VARCHAR(45) NULL,
  EXCHANGE_NAME VARCHAR(32) NOT NULL,
  FACEBOOK_URL VARCHAR(256) NULL,
  FAX_NUM VARCHAR(45) NULL,
  ROW_ID INT NOT NULL DEFAULT 0,
  LINKEDIN_URL VARCHAR(256) NULL,
  BROKER_NAME VARCHAR(256) NULL,
  REGISTRATION_NUM VARCHAR(16) NOT NULL,
  DATA_SOURCE VARCHAR(45) NULL,
  TELEPHONE_NUM VARCHAR(45) NULL,
  TRADE_NAME VARCHAR(45) NULL,
  TWITTER_URL VARCHAR(256) NULL,
  BROKER_TYPE VARCHAR(45) NULL,
  VALIDITY VARCHAR(45) NULL,
  WEBSITE_URL VARCHAR(256) NULL,
  VALIDITY_FROM DATETIME NULL,
  VALIDITY_TO DATETIME NULL,
  PRIMARY KEY (REGISTRATION_NUM, EXCHANGE_NAME)) ;

-- Create indexes
CREATE FULLTEXT INDEX BROKER_NAME_SEARCH ON BROKERS.BROKER_DETAILS  (BROKER_NAME);
CREATE FULLTEXT INDEX TRADE_NAME_SEARCH ON BROKERS.BROKER_DETAILS  (TRADE_NAME);
CREATE FULLTEXT INDEX BROKER_ADDRESS_SEARCH ON BROKERS.BROKER_DETAILS  (BROKER_ADDRESS);